@@ -57,8 +57,8 @@ public final class Samples {
         for (int j=0; j<idIndices.length; ++j) {
             int idIndex = idIndices[j];
             if (idIndexToIndex[idIndex] != -1) {
-                String s = "duplicate sample: " + sampleIds.id(idIndex) +
-                        " (ID index: " + idIndex + ")";
+                String s = "ERROR: Duplicate sample (" + sampleIds.id(idIndex) +
+                        ") in target and/or reference file";
                 throw new IllegalArgumentException(s);
             }
             else {
