@@ -68,8 +68,8 @@ public class Main {
      * The program name and version.
      */
     public static final String VERSION = "(version 5.0)";
-    public static final String PROGRAM = "beagle.28Sep18.793.jar";
-    public static final String COMMAND = "java -jar beagle.28Sep18.793.jar";
+    public static final String PROGRAM = "beagle.12Jul19.0df.jar";
+    public static final String COMMAND = "java -jar beagle.12Jul19.0df.jar";
 
     /**
      * The copyright string.
@@ -81,7 +81,7 @@ public class Main {
      */
     public static final String SHORT_HELP = Main.PROGRAM + " " + VERSION
             + Const.nl + Main.COPYRIGHT
-            + Const.nl + "Enter \"java -jar beagle.28Sep18.793.jar\" to "
+            + Const.nl + "Enter \"java -jar beagle.12Jul19.0df.jar\" to "
             + "list command line argument";
 
     private final Par par;
@@ -193,14 +193,16 @@ public class Main {
 
     private void printOutput(CurrentData cd, GT phasedTarg) {
         assert par.gt()!=null;
-        int refStart = cd.prevSpliceStart();
-        int refEnd = cd.nextSpliceStart();
         int nThreads = par.nthreads();
         if (cd.nMarkers()==cd.nTargMarkers() || par.impute() == false) {
-            windowWriter.print(phasedTarg, refStart, refEnd, nThreads);
+            int targStart = cd.prevTargetSpliceStart();
+            int targEnd = cd.nextTargetSpliceStart();
+            windowWriter.print(phasedTarg, targStart, targEnd, nThreads);
         }
         else {
             long t0 = System.nanoTime();
+            int refStart = cd.prevSpliceStart();
+            int refEnd = cd.nextSpliceStart();
             ImpData impData = new ImpData(par, cd, phasedTarg, genMap);
             AtomicReferenceArray<StateProbs> stateProbs = ImpLS.stateProbs(impData);
             windowWriter.print(impData, stateProbs, refStart, refEnd);
