@@ -98,10 +98,12 @@ public class RestrictedVcfWindow  implements Closeable {
         for (int j = fullOverlap, n=nextMarkers.nMarkers(); j<n; ++j) {
             Marker m = nextMarkers.marker(j);
             if (next!=null && next.marker().chromIndex()==m.chromIndex()) {
-                while (next != null && next.marker().pos() < m.pos()) {
+                while (next != null && next.marker().chromIndex()==m.chromIndex()
+                        && next.marker().pos()<m.pos()) {
                     next = it.hasNext() ? it.next() : null;
                 }
-                while (next != null && next.marker().pos() == m.pos()
+                while (next != null && next.marker().chromIndex()==m.chromIndex()
+                        && next.marker().pos()==m.pos()
                         && next.marker().equals(m)==false) {
                     next = it.hasNext() ? it.next() : null;
                 }
