@@ -88,8 +88,7 @@ public class TargetData implements Data {
 
     private static GT targGT(Samples samples, GTRec[] targData,
             Pedigree ped) {
-        GT gt = new BasicGT(samples, targData);
-        return gt.isGTData() ? new XBasicGT(gt, ped) : gt;
+        return new BasicGT(samples, targData);
     }
 
     @Override
