@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014 Brian L. Browning
+ * Copyright (C) 2014-2016 Brian L. Browning
  *
  * This file is part of Beagle
  *
@@ -26,6 +26,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.stream.IntStream;
 
 /**
  * <p>Class {@code VcfRecord} represents a VCF record.
@@ -35,7 +36,7 @@ import java.util.Map;
  *
  * @author Brian L. Browning {@code <browning@uw.edu>}
  */
-public final class VcfRecord implements VcfEmission {
+public final class VcfRecord implements GTRec {
 
     /**
      * The VCF FORMAT code for log-scaled genotype likelihood data: "GL".
@@ -57,7 +58,7 @@ public final class VcfRecord implements VcfEmission {
     private final String[] formatFields;
     private final Map<String, Integer> formatMap;
 
-    private final VcfEmission gtEm;
+    private final GTRec gtEm;
     private final float[] gls;
 
     /**
@@ -594,14 +595,36 @@ public final class VcfRecord implements VcfEmission {
         return gtEm == null ? -1 : gtEm.allele2(sample);
     }
 
+    @Override
+    public int get(int hap) {
+        return gtEm == null ? -1 : gtEm.get(hap);
+    }
+
+    @Override
+    public int[] alleles() {
+        if (gtEm==null) {
+            return IntStream.range(0, size())
+                    .map(h -> -1)
+                    .toArray();
+        }
+        else {
+            return gtEm.alleles();
+        }
+    }
+
     @Override
     public boolean isPhased(int sample) {
         return gtEm == null ? false : gtEm.isPhased(sample);
     }
 
     @Override
-    public boolean isRefData() {
-        return  gtEm == null ? false : gtEm.isRefData();
+    public boolean isPhased() {
+        return  gtEm == null ? false : gtEm.isPhased();
+    }
+
+    @Override
+    public boolean isGTData() {
+        return gls==null;
     }
 
     @Override
@@ -622,49 +645,16 @@ public final class VcfRecord implements VcfEmission {
         }
     }
 
-    @Override
-    public int allele(int hap) {
-        return gtEm == null ? -1 : gtEm.allele(hap);
-    }
-
     @Override
     public int nAlleles() {
         return this.marker().nAlleles();
     }
 
     @Override
-    public boolean storesNonMajorIndices() {
-        return false;
-    }
-
-    @Override
-    public int majorAllele() {
-        String s = "this.storesNonMajorIndices()==false";
-        throw new UnsupportedOperationException(s);
-    }
-
-    @Override
-    public int alleleCount(int allele) {
-        String s = "this.storesNonMajorIndices()==false";
-        throw new UnsupportedOperationException(s);
-    }
-
-    @Override
-    public int hapIndex(int allele, int copy) {
-        String s = "this.storesNonMajorIndices()==false";
-        throw new UnsupportedOperationException(s);
-    }
-
-    @Override
-    public int nHaps() {
+    public int size() {
         return 2*vcfHeader.nSamples();
     }
 
-    @Override
-    public int nHapPairs() {
-        return vcfHeader.nSamples();
-    }
-
     /**
      * Returns the VCF record.
      * @return the VCF record
