@@ -48,7 +48,7 @@ public final class VcfWriter {
     private static final String gtFormat = "##FORMAT=<ID=GT,Number=1,Type=String,"
             + "Description=\"Genotype\">";
     private static final String dsFormat = "##FORMAT=<ID=DS,Number=A,Type=Float,"
-            +"Description=\"estimated ALT dose [P(RA) + P(AA)]\">";
+            +"Description=\"estimated ALT dose [P(RA) + 2*P(AA)]\">";
     private static final String ap1Format = "##FORMAT=<ID=AP1,Number=A,Type=Float,"
             +"Description=\"estimated ALT dose on first haplotype\">";
     private static final String ap2Format = "##FORMAT=<ID=AP2,Number=A,Type=Float,"
